| Title: | Return a Random Joke from APIs |
|---|---|
| Description: | What is funnier than a joke? A joke in R! This package utilizes the APIs for <https://icanhazdadjoke.com> and <https://chucknorris.io> and returns a random dadjoke or Chuck Norris joke. |
| Authors: | Tan Ho [aut, cre], Jeffrey W Hollister [aut], Mathias Schilling [cph], Antoine Bichat [ctb], Brett Langdon [cph] |
| Maintainer: | Tan Ho <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-17 09:11:12 UTC |
| Source: | https://github.com/tanho63/joker |
This function returns a random Chuck Norris joke from https://chucknorris.io
chuckjoke(sfw = TRUE)chuckjoke(sfw = TRUE)
sfw |
(Defaults to TRUE) Filters out explicit, political, and religion jokes from the potential returns. |
A random Chuck Norris joke from https://chucknorris.io
chuckjoke() chuckjoke(sfw=FALSE)chuckjoke() chuckjoke(sfw=FALSE)
This function returns a random dad joke from https://icanhazdadjoke.com
dadjoke()dadjoke()
dadjoke()dadjoke()
This function chooses a joke to return, calling either dadjoke() or chuckjoke() at random.
randomjoke()randomjoke()
randomjoke()randomjoke()